Frequently Asked Questions — Kombu v0.1.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Kombu v0.1.0 documentation »

# Frequently Asked Questions

## Questions

### Q: Message.reject doesn’t work?

Answer: RabbitMQ (as of v1.5.5) has not implemented reject yet. There was a brief discussion about it on their mailing list, and the reason why it’s not implemented yet is revealed:

http://lists.rabbitmq.com/pipermail/rabbitmq-discuss/2009-January/003183.html

### Q: Message.requeue doesn’t work?

Answer: See Message.reject doesn’t work?

### Navigation

- index
- modules |
- next |
- previous |
- Kombu v0.1.0 documentation »